==> SV1000-Linux.SV1.2.109.tar.gz: SpliceCom/WebManager/admin/managecontacts/contactForm.php <==
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Cache-Control" content="no-cache, no-store, must-revalidate" />
<meta http-equiv="Pragma" content="no-cache" />
<meta http-equiv="Expires" content="0" />
</head>
<?php 
require('../assets/inc/ldapConnect.php');
require('loadContact.php');
?>

<body>
<!-- Element to pop up -->
<div style='background-color:#dddddd; border: 4px solid black; padding: 5px; height: 565px; width: 1015px;'>

<div id="wrapper">
        <ul id="tabs">
            <li class="active">Contact</li>
			<li>Contact Details</li>
        </ul>
        <ul id="tab">
		<form id='new_contact'>
		<!-- first tab -->
            <li class="active">
                <h2><span id='contactFormIcon' class=<?php echo $contactClass ?>></span> <span id='contactFormText'><?php if (strlen($contactNumber) >= 1) echo "'Contact: " . $contactNumber . "' "; echo $contactText ?></span></h2>
				
				
				<!-- #left -->
				<div class="colLeft">

					<div class='field'>
						<label class='grey' for="cn">Contact Name</label>
						<input type='text' id='cn' name='cn' value='<?php echo $cn ?>' >
						<span class='information'>CONTACT NAME</span>
					</div>
										
					<div class='field'>
						<label class='grey' for="o">Company Name</label>
						<input type='text' id='o' name='o' value='<?php echo $o ?>' >
						<span class='information'>CONTACT COMPANY</span>
					</div>
					
					<div class='field'>
						<label class='grey' for="description">Description</label>
						<input type='text' id='description' name='description' value='<?php echo $description ?>' >
						<span class='information'>CONTACT DESCRIPTION</span>
					</div>
					
					<div class='field'>
						<label class='grey' for="telephonenumber">Telephone Number</label>
						<input type='text' id='telephonenumber' name='telephonenumber' value='<?php echo $telephonenumber ?>' >
						<span class='information'>CONTACT TELEPHONE NUMBER</span>
					</div>
					
				</div> 
				<!-- #left -->
				
				
				<!-- #right -->
				<div class="colRight">
				
					<div class='field'>
						<label class='grey' for="mobiletelephonenumber">Mobile Telephone Number</label>
						<input type='text' id='mobiletelephonenumber' name='mobiletelephonenumber' value='<?php echo $mobiletelephonenumber ?>' >
						<span class='information'>CONTACT MOBILE TELEPHONE NUMBER</span>
					</div>
					
					<div class='field'>
						<label class='grey' for="hometelephonenumber">Home Telephone Number</label>
						<input type='text' id='hometelephonenumber' name='hometelephonenumber' value='<?php echo $hometelephonenumber ?>' >
						<span class='information'>CONTACT HOME TELEPHONE NUMBER</span>
					</div>
					
					<div class='field'>
						<label class='grey' for="spare1telephonenumber">Spare 1 Telephone Number</label>
						<input type='text' id='spare1telephonenumber' name='spare1telephonenumber' value='<?php echo $spare1telephonenumber ?>' >
						<span class='information'>CONTACT SPARE 1 TELEPHONE NUMBER</span>
					</div>

					<div class='field'>
						<label class='grey' for="spare2telephonenumber">Spare 2 Telephone Number</label>
						<input type='text' id='spare2telephonenumber' name='spare2telephonenumber' value='<?php echo $spare2telephonenumber ?>' >
						<span class='information'>CONTACT SPARE 2 TELEPHONE NUMBER</span>
					</div>
	
				</div> 
				<!-- #right -->
			</li>	
			<!-- first tab -->
			
			<!-- second tab -->
			<li class="warnings">
                <h2><span id='contactFormIcon' class=<?php echo $contactClass ?>></span> <span id='contactFormText'><?php if (strlen($contactNumber) >= 1) echo "'Contact: " . $contactNumber . "' "; echo $contactText ?></span></h2>
				<!-- #left -->
				<div class="colLeft">

					<div class='field'>
						<label class='grey' for="directrouteto">Direct Route To</label>
						<input type='text' id='directrouteto' name='directrouteto' value='<?php echo $directrouteto ?>' >
						<span class='information'>CONTACT DIRECT ROUTE TO</span>
					</div>
										
					<div class='field'>
						<label class='grey' for="mail">Email Address</label>
						<input type='text' id='mail' name='mail' value='<?php echo $mail ?>' >
						<span class='information'>CONTACT EMAIL ADDRESS</span>
					</div>
					
					<div class='field'>
						<label class='grey' for="priorityboost">Priority Boost</label>
						<input type='text' id='priorityboost' name='priorityboost' value='<?php echo $priorityboost ?>' >
						<span class='information'>CONTACT PRIORITY BOOST</span>
					</div>
				
				</div> 
				<!-- #left -->
				
				
				<!-- #right -->
				<div class="colRight">
				
					<div class='field'>
						<label class='grey' for="ouraccount">Account (our ref)</label>
						<input type='text' id='ouraccount' name='ouraccount' value='<?php echo $ouraccount ?>' >
						<span class='information'>CONTACT ACCOUNT (OUR REF)</span>
					</div>
					
					<div class='field'>
						<label class='grey' for="theiraccount">Account (their ref)</label>
						<input type='text' id='theiraccount' name='theiraccount' value='<?php echo $theiraccount ?>' >
						<span class='information'>CONTACT ACCOUNT (THEIR REF)</span>
					</div>
					
					<div class='field'>
						<label class='grey' for="ambiguoustelephonenumber">Ambiguous Telephone Number</label>
						<input type='text' id='ambiguoustelephonenumber' name='ambiguoustelephonenumber' value='<?php echo $ambiguoustelephonenumber ?>' >
						<span class='information'>CONTACT AMBIGUOUS TELEPHONE NUMBER</span>
					</div>
					
				</div> 
				<!-- #right -->
				</li>
				<!-- second tab -->
			
			<div class='formFooter'>
				<div class='left' id='msg_wrap'>
					<span id='msg'></span>
				</div>
			
				<div class='right'>
				<input type='hidden' name='selectedCompany' id='selectedCompany' value='<?php echo $selectedCompany ?>' />
				<input type='hidden' id='contactMode' name='contactMode' value='<?php echo $contactMode ?>'>
				
				<input type='button' class='close' id ='close' value='Close'/>
				<input type='button' class='save' id='save' value='Save'/>
				</div>
			</div>
			</form>
		</ul>
    </div>

</div>	
</body>
</html>

==> SV1000-Linux.SV1.3.82.tar.gz: SpliceCom/WebManager/admin/managecontacts/contactForm.php <==
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Cache-Control" content="no-cache, no-store, must-revalidate" />
<meta http-equiv="Pragma" content="no-cache" />
<meta http-equiv="Expires" content="0" />
</head>
<?php 
require('../assets/inc/ldapConnect.php');
require('loadContact.php');
?>

<body>
<!-- Element to pop up -->
<div style='background-color:#dddddd; border: 4px solid black; padding: 5px; height: 565px; width: 1015px;'>

<div id="wrapper">
        <ul id="tabs">
            <li class="active">Contact</li>
			<li>Contact Details</li>
        </ul>
        <ul id="tab">
		<form id='new_contact'>
		<!-- first tab -->
            <li class="active">
                <h2><span id='contactFormIcon' class=<?php echo $contactClass ?>></span> <span id='contactFormText'><?php if (strlen($contactNumber) >= 1) echo "'Contact: " . $contactNumber . "' "; echo $contactText ?></span></h2>
				
				
				<!-- #left -->
				<div class="colLeft">

					<div class='field'>
						<label class='grey' for="cn">Contact Name</label>
						<input type='text' id='cn' name='cn' value='<?php echo $cn ?>' >
						<span class='information'>CONTACT NAME</span>
					</div>
										
					<div class='field'>
						<label class='grey' for="o">Company Name</label>
						<input type='text' id='o' name='o' value='<?php echo $o ?>' >
						<span class='information'>CONTACT COMPANY</span>
					</div>
					
					<div class='field'>
						<label class='grey' for="description">Description</label>
						<input type='text' id='description' name='description' value='<?php echo $description ?>' >
						<span class='information'>CONTACT DESCRIPTION</span>
					</div>
					
					<div class='field'>
						<label class='grey' for="telephonenumber">Telephone Number</label>
						<input type='text' id='telephonenumber' name='telephonenumber' value='<?php echo $telephonenumber ?>' >
						<span class='information'>CONTACT TELEPHONE NUMBER</span>
					</div>
					
					<div class='field'>
						<label class='grey' for="mobiletelephonenumber">Mobile Telephone Number</label>
						<input type='text' id='mobiletelephonenumber' name='mobiletelephonenumber' value='<?php echo $mobiletelephonenumber ?>' >
						<span class='information'>CONTACT MOBILE TELEPHONE NUMBER</span>
					</div>
					
				</div> 
				<!-- #left -->
				
				
				<!-- #right -->
				<div class="colRight">
				
					<div class='field wide'>
						<label class='grey' for="givenname">First & Last Name</label>
						<input type='text' class='smallFields' id='givenname' name='givenname' value='<?php echo $firstname ?>' >
						<input type='text' class='smallFields' id='sn' name='sn' value='<?php echo $lastname ?>' >
						<span class='information'>USERS FIRST AND LAST NAMES</span>
					</div>
				
					<div class='field'>
						<label class='grey' for="hometelephonenumber">Home Telephone Number</label>
						<input type='text' id='hometelephonenumber' name='hometelephonenumber' value='<?php echo $hometelephonenumber ?>' >
						<span class='information'>CONTACT HOME TELEPHONE NUMBER</span>
					</div>
					
					<div class='field'>
						<label class='grey' for="spare1telephonenumber">Spare 1 Telephone Number</label>
						<input type='text' id='spare1telephonenumber' name='spare1telephonenumber' value='<?php echo $spare1telephonenumber ?>' >
						<span class='information'>CONTACT SPARE 1 TELEPHONE NUMBER</span>
					</div>

					<div class='field'>
						<label class='grey' for="spare2telephonenumber">Spare 2 Telephone Number</label>
						<input type='text' id='spare2telephonenumber' name='spare2telephonenumber' value='<?php echo $spare2telephonenumber ?>' >
						<span class='information'>CONTACT SPARE 2 TELEPHONE NUMBER</span>
					</div>
	
				</div> 
				<!-- #right -->
			</li>	
			<!-- first tab -->
			
			<!-- second tab -->
			<li class="warnings">
                <h2><span id='contactFormIcon' class=<?php echo $contactClass ?>></span> <span id='contactFormText'><?php if (strlen($contactNumber) >= 1) echo "'Contact: " . $contactNumber . "' "; echo $contactText ?></span></h2>
				<!-- #left -->
				<div class="colLeft">

					<div class='field'>
						<label class='grey' for="directrouteto">Direct Route To</label>
						<input type='text' id='directrouteto' name='directrouteto' value='<?php echo $directrouteto ?>' >
						<span class='information'>CONTACT DIRECT ROUTE TO</span>
					</div>
										
					<div class='field'>
						<label class='grey' for="mail">Email Address</label>
						<input type='text' id='mail' name='mail' value='<?php echo $mail ?>' >
						<span class='information'>CONTACT EMAIL ADDRESS</span>
					</div>
					
					<div class='field'>
						<label class='grey' for="priorityboost">Priority Boost</label>
						<input type='text' id='priorityboost' name='priorityboost' value='<?php echo $priorityboost ?>' >
						<span class='information'>CONTACT PRIORITY BOOST</span>
					</div>
				
				</div> 
				<!-- #left -->
				
				
				<!-- #right -->
				<div class="colRight">
				
					<div class='field'>
						<label class='grey' for="ouraccount">Account (our ref)</label>
						<input type='text' id='ouraccount' name='ouraccount' value='<?php echo $ouraccount ?>' >
						<span class='information'>CONTACT ACCOUNT (OUR REF)</span>
					</div>
					
					<div class='field'>
						<label class='grey' for="theiraccount">Account (their ref)</label>
						<input type='text' id='theiraccount' name='theiraccount' value='<?php echo $theiraccount ?>' >
						<span class='information'>CONTACT ACCOUNT (THEIR REF)</span>
					</div>
					
					<div class='field'>
						<label class='grey' for="ambiguoustelephonenumber">Ambiguous Telephone Number</label>
						<input type='text' id='ambiguoustelephonenumber' name='ambiguoustelephonenumber' value='<?php echo $ambiguoustelephonenumber ?>' >
						<span class='information'>CONTACT AMBIGUOUS TELEPHONE NUMBER</span>
					</div>
					
				</div> 
				<!-- #right -->
				</li>
				<!-- second tab -->
			
			<div class='formFooter'>
				<div class='left' id='msg_wrap'>
					<span id='msg'></span>
				</div>
			
				<div class='right'>
				<input type='hidden' name='selectedCompany' id='selectedCompany' value='<?php echo $selectedCompany ?>' />
				<input type='hidden' id='contactMode' name='contactMode' value='<?php echo $contactMode ?>'>
				
				<input type='button' class='close' id ='close' value='Close'/>
				<input type='button' class='save' id='save' value='Save'/>
				</div>
			</div>
			</form>
		</ul>
    </div>

</div>	
</body>
</html>
